@@ -6,7 +6,7 @@ import numpy as np
 
 from .tract_python import ffi, lib
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 
 def string_at(ptr):
@@ -18,6 +18,9 @@ class TractModel:
         self._typed_model_plan_ptr = typed_model_plan_ptr
         self._original_path = original_path
 
+    def __del__(self):
+        lib.tract_destroy_plan(self._typed_model_plan_ptr)
+
     @classmethod
     def load_from_path(cls, path: T.Union[Path, str]):
         path = Path(path)
@@ -63,6 +66,7 @@ class TractModel:
         )
         outputs_buffer_len = ffi.unpack(npz_outputs_buffer_length_ref, 1)[0]
         raw_output_bytes = ffi.unpack(raw_output_ref[0], outputs_buffer_len)
+        lib.tract_destroy_buffer(raw_output_ref[0])
 
         if exit_code:
             lib_error = ffi.new("char * *")
